Test Select Events
open | ../tests/html/test_form_events.html |
verifyValue | theSelect |
verifyValue | eventlog |
select | theSelect | First Option
verifyValue | theSelect | option1
verifyValue | eventlog | {focus(theSelect)} {change(theSelect)}
type | eventlog |
select | theSelect | First Option
verifyValue | theSelect | option1
verifyValue | eventlog | {focus(theSelect)}
type | eventlog |
select | theSelect | Empty Option
verifyValue | theSelect |
verifyValue | eventlog | {focus(theSelect)} {change(theSelect)}